@@ -1408,7 +1408,11 @@ var DimpCompose = {
         /* Attach event handlers. */
         if (Prototype.Browser.IE) {
             // IE doesn't bubble change events.
-            $('identity', 'upload').invoke('observe', 'change', this.changeHandler.bindAsEventListener(this));
+            $('identity', 'upload').compact().invoke(
+                'observe',
+                'change',
+                this.changeHandler.bindAsEventListener(this)
+            );
         } else {
             document.observe('change', this.changeHandler.bindAsEventListener(this));
         }
