@@ -66,7 +66,7 @@ class IMP_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (6.2.12)';
+    public $version = 'H5 (6.2.14)';
 
     /**
      * Server key used in logged out session.
@@ -606,8 +606,9 @@ class IMP_Application extends Horde_Registry_Application
     /* Exception handler. */
 
     /**
+     * @todo Type hint with Throwable in H6.
      */
-    public function exceptionHandler(Exception $e)
+    public function exceptionHandler($e)
     {
         if ($e instanceof Horde_Imap_Client_Exception) {
             $e = new Horde_Exception_AuthenticationFailure(
